from setuptools import setup

setup(
    name='booInfer',
    version='0.0.1',
    description='',
    long_description='',
    url='',
    author='Žiga Pušnik',
    author_email='ziga.pusnik@fri.uni-lj.si',
    packages=[],
    classifiers=[], 
)